#ifndef QTENGINE_QT_WRAPPER_H
#define QTENGINE_QT_WRAPPER_H

#include <gtk/gtknotebook.h>

#ifdef __cplusplus
extern "C" {

class CachedImage
{
	// This class helps speed up image drawing.  It holds one
	// pixmap, in a format ready to be passed to GDK, of a widget
	// of a specified size and type

public:
	enum WidgetType
	{
		Button,
		Tab,
		LineEdit,
		ComboBox,
		Frame,
		CheckBox,
		RadioButton,
		MenuItem,
		MenuBar,
		Splitter,
		TabFrame,
		Menu
	};

	CachedImage() {};
	CachedImage(WidgetType t, GtkStateType s, int w, int h, QImage i);
	CachedImage(WidgetType t, GtkStateType s, int w, int h, QImage i, int extra);

	WidgetType type;
	GtkStateType state_type;
	int width;
	int height;
	QImage image;

	int on; // For Check Boxes
	int hasFocus; // For Line Edits
};

void cacheAppend(CachedImage image);

#endif

void createQApp();
void destroyQApp();
void setColors(GtkStyle* style);
void drawButton(GdkWindow * window, GtkStyle * style, GtkStateType state_type, int x, int y, int width, int height);
void drawTab(GdkWindow * window, GtkStyle * style, GtkStateType state_type, int x, int y, int width, int height);
void drawVLine(GdkWindow * window, GtkStyle * style, GtkStateType state_type, int x, int y1, int y2);
void drawHLine(GdkWindow * window, GtkStyle * style, GtkStateType state_type, int y, int x1, int x2);
void drawLineEdit(GdkWindow * window, GtkStyle * style, GtkStateType state_type, int hasFocus, int x, int y, int width, int height);
void drawComboBox(GdkWindow * window, GtkStyle * style, GtkStateType state_type, int x, int y, int width, int height);
void drawFrame(GdkWindow * window, GtkStyle * style, GtkStateType state_type, GtkShadowType shadow_type, int x, int y, int width, int height);
void drawCheckBox(GdkWindow * window, GtkStyle * style, GtkStateType state_type, int on, int x, int y, int width, int height);
void drawRadioButton(GdkWindow * window, GtkStyle * style, GtkStateType state_type, int on, int x, int y, int width, int height);
void drawScrollBar(GdkWindow * window, GtkStyle * style, GtkStateType state_type, int orientation, GtkAdjustment* adj, int x, int y, int width, int height);
void drawSplitter(GdkWindow * window, GtkStyle * style, GtkStateType state_type, int orientation, int x, int y, int width, int height);
void drawMenuBarItem(GdkWindow * window, GtkStyle * style, GtkStateType state_type, int x, int y, int width, int height);
void drawMenuItem(GdkWindow * window, GtkStyle * style, GtkStateType state_type, int x, int y, int width, int height);
void drawMenu(GdkWindow * window, GtkStyle * style, GtkStateType state_type, int x, int y, int width, int height);
void drawTabFrame(GdkWindow * window, GtkStyle * style, GtkStateType state_type, int x, int y, int width, int height);

#ifdef  __cplusplus
}
#endif

#endif
